[![Test Status](https://github.com/FarmBot/farmbot-py/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/FarmBot/farmbot-py/actions?query=branch%3Amain)
[![Coverage Status](https://coveralls.io/repos/github/FarmBot/farmbot-py/badge.svg?branch=main)](https://coveralls.io/github/FarmBot/farmbot-py?branch=main)
[![PyPI - Version](https://img.shields.io/pypi/v/farmbot)](https://pypi.org/project/farmbot/)

See [FarmBot-Py](https://developer.farm.bot/docs/farmbot-py) in the FarmBot developer documentation.
